#
# spec file for package wcm
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define major_ver 0.9
%define minor_ver 0
Name:           wcm
Version:        %{major_ver}.%{minor_ver}
Release:        1.1
Summary:        Wayfire Config Manager
License:        MIT
Url:            https://wayfire.org/
Source0:        https://github.com/WayfireWM/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/WayfireWM/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz.sha256sum
BuildRequires:  meson
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(wayfire)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(wf-config) >= %{major_ver}
BuildRequires:  pkgconfig(wf-shell) >= %{major_ver}
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(xkbregistry)
BuildRequires:  pkgconfig(wlroots) >= 0.17.0
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
Requires:       wayfire >= %{major_ver}
Requires:       wdisplays >= %{major_ver}

%description
Wayfire Config Manager https://wayfire.org/.

%prep
echo "`grep %{name}-%{version}.tar.xz %{SOURCE1} | grep -Eo '^[0-9a-f]+'`  %{SOURCE0}" | sha256sum -c
%autosetup -p1

%build
# Disable including wdisplays.  It's already packaged in Factory, added Requires: for the distro package
%meson -Denable_wdisplays=false
%meson_build

%install
%meson_install

%check
%meson_test

%files
%license LICENSE
%{_bindir}/%{name}
%dnl %{_bindir}/wdisplays
%{_datadir}/wayfire/icons
%{_datadir}/icons/hicolor/*
%{_datadir}/applications/*.desktop

%changelog
* Tue Jan  7 2025 Shawn Dunn <sfalken@opensuse.org>
- Add -Denable_wldisplays=false to build.
  * wdisplays is already packaged and available in :Factory, added
    Requires: to package for the already packaged wdisplays
- Remove deprecated %%suse_update_desktop_file from the %%install
  section
* Sun Jan  5 2025 Shawn Dunn <sfalken@opensuse.org>
- Update to pkgconfig(wlroots) >= 0.17.0
  * Build is choking, because there are three versions of wlroots
    available
* Mon Aug 26 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.9.0:
  * No changelog was made available.
* Mon Oct  9 2023 dead_mozay@opensuse.org
- Update to version 0.8.0:
  * `PluginPage`: set_scrollable(true), s.t. it looks ok with panel config page (there are many groups) (#63)
  * make wcm search user directories for icons (#61)
  * Added LXQt-shell plugin icon (#60)
  * Center plugins description (#59)
  * XKB layouts option: suggest available layouts in the context menu (#58)
  * plugin name label: set_justify(center) (#57)
  * Make color button editor show alpha slider (#56)
  * Fix ordering of combo boxes (#53)
  * Present window when wcm is run again (#50)
  * add 'config' and 'shell-config' command line options (#49)
  * vswitch bindings dynamic list widget (#46)
  * make buttons on main page be the same size (old behavior) (#45)
  * Add vertical spacing around separators on the main page
  * change window defaut size; set min children per line for flowbox
  * fix: show command name for empty commands
  * expand `BindingWidget` when command is empty
  * use `#pragma once` instead of `#ifndef/#define/#endif`
  * `KeyEntry::check_and_confirm`: fix condition for showing dialog
  * Enabling/disabling plugins
  * `BindingWidget`: adding new binding
  * `BindingWidget`: removing
  * `BindingWidget`: changing binding type
  * Saving; Fix KeyEntry modifiers names; Autostart: add/remove
  * Init pointers with nullptr: doesn't work sometimes without it
  * update screenshot; add tooltips in `AutostartWidget`
  * abstract KeyEntry from Option; reset button now do something
  * key grab: fix grabbing Esc and Tab
  * use Gtk::SearchEntry
  * key grab
  * key entry: no modifiers confirm dialog
  * file chooser dialogs; better dynamic lists
  * Command widget; better key entry widget
  * Saving and dynamic list options prototyping
  * fix Gdk::RGBA initializing
  * rewrite to gtkmm and refactor: without saving
  * Respect defaults from defaults.ini if it exists
  * Add transition animation (#38)
  * Add new icons to `meson.build` (#37)
  * Add more icons
  * Change icon "back" to "go-previous" (#34)
  * Reset colors for all formats (#36)
  * Only open wdisplays with specific keys when widget is focused
  * autostart: fix support for dynamic lists (#31)
* Tue Jan 17 2023 dead_mozay@opensuse.org
- Update to version 0.7.5:
  * Respect defaults from defaults.ini if it exists
  * Add transition animation (#38)
  * Add more icons
  * Change icon "back" to "go-previous" (#34)
  * Reset colors for all formats (#36)
  * Only open wdisplays with specific keys when widget is focused
  * autostart: fix support for dynamic lists (#31)
  * Use better margin choices for left panel buttons
* Fri Dec  2 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update wlroots minimum version to spec.
* Wed Nov 30 2022 Dead Mozay <dead_mozay@opensuse.org>
- Set wlroots max version to spec.
* Wed Feb  3 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.0:
  * No changelog was made available.
* Mon Nov  9 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.0:
  * No changelog was made available.
* Mon Aug 17 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.5.0:
  * No changelog was made available.
* Thu Apr 30 2020 Dead Mozay <dead_mozay@opensuse.org>
- Remove _service
* Mon Mar 23 2020 dead_mozay@opensuse.org
- Update to version v0.4.0:
  * No changelog was made available.
* Mon Mar 23 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
